package view;

import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Application exemple sur le dcoupage d'une image avec Swing
 * pour en extraire une image partielle.
 * 
 * @author Mickal Martin Nevot
 * 
 * @version 1.2.0
 */
public class JFrameSample4 extends JFrame {

	private static final long serialVersionUID = 1L;

	private static final int FRAME_WIDTH = 300;
	private static final int FRAME_HEIGHT = 200;
	
	private static final String BASE_IMG_URI = "img/";  //  @jve:decl-index=0:

	private static final int PARTIAL_IMAGE_WIDTH = 100;
	private static final int PARTIAL_IMAGE_HEIGHT = 150;
	
	private JPanel jContentPane1 = null;

	private JLabel jLLabel1 = null;
	
	/**
	 * This is the default constructor
	 */
	public JFrameSample4() {
		super();
		initialize();
	}

	/**
	 * This method initializes this
	 */
	private void initialize() {
		this.setTitle("MyJFrameSample4Title"); // On donne un titre  l'application
		this.setSize(FRAME_WIDTH, FRAME_HEIGHT); // On donne une taille  notre fentre
		this.setLocationRelativeTo(null); // On centre la fentre  l'cran
		this.setResizable(false); //On interdit le redimensionnement de la fentre
		this.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE); //On dit  l'application de se fermer lors du clic sur la croix
		this.setContentPane(getJContentPane1());
	}

	/**
	 * This method initializes this.jContentPane1
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJContentPane1() {
		if (this.jContentPane1 == null) {
			this.jContentPane1 = new JPanel();
			this.jContentPane1.setLayout(null);
			this.jContentPane1.add(getjLLabel1(), null);
		}
		
		return this.jContentPane1;
	}
	
	/**
	 * This method initializes this.jLLabel1	
	 * 	
	 * @return javax.swing.JLabel	
	 */
	private JLabel getjLLabel1() {
		if (this.jLLabel1 == null) {
			this.jLLabel1 = new JLabel();
			this.jLLabel1.setName("jLLabel1");
			// N'ayant pas de gestionnaire de positionnement (Layout) dans cette application,
			// On centre this.jLLabel1 (qui va contenir l'image partielle) de la manire suivante
			this.jLLabel1.setBounds(new Rectangle(FRAME_WIDTH / 2 - PARTIAL_IMAGE_WIDTH / 2, (FRAME_HEIGHT - PARTIAL_IMAGE_HEIGHT) / 4, PARTIAL_IMAGE_WIDTH, PARTIAL_IMAGE_HEIGHT));
			this.jLLabel1.setText(null);
			
			BufferedImage bMainImage = null;
			BufferedImage bPartialImage = null;
			// L'appel  la mthode read doit tre contenu dans un bloc try/catch car 
			// read est succeptible de lancer une exception
			try {
				// bMainImage est de type Image, donc on doit le charger de la manire suivante
				bMainImage = ImageIO.read(getClass().getClassLoader().getResource(BASE_IMG_URI + "java.png"));
			} catch (IOException e) {
				e.printStackTrace();
			}
			// On extrait une partie de bMainImage 
			bPartialImage = bMainImage.getSubimage(150, 70, PARTIAL_IMAGE_WIDTH, PARTIAL_IMAGE_HEIGHT);
			
			// On convertit le type de bPartialImage en ImageIcon pour pouvoir l'afficher dans this.jLLabel1
			this.jLLabel1.setIcon(new ImageIcon(bPartialImage));
		}
		
		return this.jLLabel1;
	}
}